Skip to contents

Generates synthetic data, i.e., the Swiss role to test different manifold learning techniques

Usage

rs_data_swiss_role(n_samples, noise, seed)

Arguments

n_samples

Integer. Number of data points to generate.

noise

Numeric. How much noise to add.

seed

Integer. For reproducibility purposes

Value

The Swiss role synthetic data with the desired parameters.