calc_silhouette_score.Rd
If the membership has only one group, the function will return NaN for mean_silhouette and silhouette_scores.
NaN
mean_silhouette
silhouette_scores
calc_silhouette_score(data, membership)
Numerical matrix. Samples x features. The matrix that was used to generate the clustering.
Integer vector. Membership/assignment of the clustering algorithm.
A list with the following items:
mean_silhouette - The average Silhouette scores across all the data points.
silhouette_scores - The individual Silhouette scores of all the data points.