Generates the SwissRole data
rs_data_biased_swiss_role.RdGenerates synthetic data, i.e., the Swiss role to test different manifold learning techniques
Arguments
- n_samples
Integer. Number of data points to generate.
- noise
Numeric. How much noise to add.
- bias
Numeric. Sampling bias along
t.0.0recovers uniform sampling; higher values concentrate samples at the inner end of the roll. A value of2.5mirrors the trajectory accumulation behaviour.- seed
Integer. For reproducibility purposes