Run PHATE dimensionality reduction from a precomputed kNN graph
rs_phate_from_knn.RdWrapper function into the Rust interface for PHATE using a precomputed kNN graph. Useful when iterating over diffusion parameters without repeating the neighbour search.
Arguments
- embd
Numerical matrix. The data to embed of shape samples x features.
- knn_data
NearestNeighboursclass from R.- n_dim
Integer. Number of PHATE dimensions to return. Currently only
2Lis supported.- k
Integer. Number of nearest neighbours used during graph construction. Must match the k used to generate
knn_data.- phate_params
Named list. Contains all key parameters for PHATE, see
params_phate()andparams_nn().- seed
Integer. Seed for reproducibility.
- verbose
Boolean. Controls verbosity of the function.